round2: round2

View source: R/utilities.R

round2R Documentation

round2

Description

Round a number to a specified number of decimal places.

Usage

round2(x, digits = digits)

Arguments

x

The numeric input to be rounded.

digits

The number of decimal places to round to, Default: digits

Details

This function rounds the input number to the specified number of decimal places.

Value

The rounded numeric value.


lulab.utils documentation built on Nov. 5, 2025, 6:02 p.m.