| round2 | R Documentation |
Round a number to a specified number of decimal places.
round2(x, digits = digits)
x |
The numeric input to be rounded. |
digits |
The number of decimal places to round to, Default: digits |
This function rounds the input number to the specified number of decimal places.
The rounded numeric value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.